.. _askbot.management.commands:

:mod:`askbot.management.commands`
==========================

.. automodule:: askbot.management.commands
    :members:
    :undoc-members:
    :show-inheritance:

.. _modules::

:mod:`Modules`
-------


* :ref:`askbot.management.commands.base_command`
* :ref:`askbot.management.commands.clean_award_badges`
* :ref:`askbot.management.commands.message_to_everyone`
* :ref:`askbot.management.commands.multi_award_badges`
* :ref:`askbot.management.commands.once_award_badges`
* :ref:`askbot.management.commands.pg_base_command`
* :ref:`askbot.management.commands.pg_clean_award_badges`
* :ref:`askbot.management.commands.pg_multi_award_badges`
* :ref:`askbot.management.commands.pg_once_award_badges`
* :ref:`askbot.management.commands.sample_command`
* :ref:`askbot.management.commands.send_email_alerts`
* :ref:`askbot.management.commands.subscribe_everyone`
* :ref:`askbot.management.commands.add_admin`
* :ref:`askbot.management.commands.remove_admin`

